Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(287)

Unified Diff: printing/pdf_metafile_skia.h

Issue 2686033005: Move metafile printing code from platform canvas to PaintCanvas (Closed)
Patch Set: Fix missing build_config include Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « printing/metafile_skia_wrapper.cc ('k') | printing/pdf_metafile_skia.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: printing/pdf_metafile_skia.h
diff --git a/printing/pdf_metafile_skia.h b/printing/pdf_metafile_skia.h
index cb69b91685746a42222e3da40aaf5d2344ff455c..948e27f45e088f54ad91072040f4865e2f5b2796 100644
--- a/printing/pdf_metafile_skia.h
+++ b/printing/pdf_metafile_skia.h
@@ -11,6 +11,7 @@
#include "base/macros.h"
#include "build/build_config.h"
+#include "cc/paint/paint_canvas.h"
#include "printing/metafile.h"
#include "skia/ext/platform_canvas.h"
@@ -18,8 +19,6 @@
#include <windows.h>
#endif
-class SkCanvas;
-
namespace printing {
enum SkiaDocumentType {
@@ -73,13 +72,13 @@ class PRINTING_EXPORT PdfMetafileSkia : public Metafile {
// This method calls StartPage and then returns an appropriate
// PlatformCanvas implementation bound to the context created by
// StartPage or NULL on error. The SkCanvas pointer that
// is returned is owned by this PdfMetafileSkia object and does not
// need to be ref()ed or unref()ed. The canvas will remain valid
// until FinishPage() or FinishDocument() is called.
- SkCanvas* GetVectorCanvasForNewPage(const gfx::Size& page_size,
- const gfx::Rect& content_area,
- const float& scale_factor);
+ cc::PaintCanvas* GetVectorCanvasForNewPage(const gfx::Size& page_size,
+ const gfx::Rect& content_area,
+ const float& scale_factor);
private:
std::unique_ptr<PdfMetafileSkiaData> data_;
« no previous file with comments | « printing/metafile_skia_wrapper.cc ('k') | printing/pdf_metafile_skia.cc » ('j') | no next file with comments »
@@ -73,13 +72,13 @@ class PRINTING_EXPORT PdfMetafileSkia : public Metafile {
// This method calls StartPage and then returns an appropriate
// PlatformCanvas implementation bound to the context created by
- // StartPage or NULL on error. The SkCanvas pointer that
+ // StartPage or NULL on error. The PaintCanvas pointer that
// is returned is owned by this PdfMetafileSkia object and does not
// need to be ref()ed or unref()ed. The canvas will remain valid

Powered by Google App Engine
This is Rietveld 408576698